@@ -10,6 +10,7 @@ logger = logging.getLogger(__name__)
 def log_event(name: str, request: Request or None = None, data: dict or None = None, ip: str = ''):
     """
     Logs consistent event for easy parsing/analysis.
+    Format: EVENT_<UPPERCASE_NAME>: <JSON object>
     :param name: Name of the event. Will be logged as EVENT_XXX with XXX in capitals.
     :param request: Django REST framework Request (optional)
     :param data: Even data (optional)
@@ -22,6 +23,4 @@ def log_event(name: str, request: Request or None = None, data: dict or None = N
         log_data['ip'] = ip
     if data:
         log_data['data'] = data
-
-    msg = 'EVENT_{}: {}'.format(name.upper(), json.dumps(log_data))
-    logger.info(msg)
+    logger.info('EVENT_%s: %s', name.upper(), json.dumps(log_data))
